/*
 * Copyright (c) 1997-1999 University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the Flux OSKit.  The OSKit is free software, also known
 * as "open source;" you can redistribute it and/or modify it under the terms
 * of the GNU General Public License (GPL), version 2, as published by the Free
 * Software Foundation (FSF).  To explore alternate licensing terms, contact
 * the University of Utah at csl-dist@cs.utah.edu or +1-801-585-3271.
 * 
 * The OSKit is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GPL for more details.  You should have
 * received a copy of the GPL along with the OSKit; see the file COPYING.  If
 * not, write to the FSF, 59 Temple Place #330, Boston, MA 02111-1307, USA.
 */
#include "X.h"
#include "scrnintstr.h"

#include "xf86.h"
#include "xf86Priv.h"
#include "xf86_OSlib.h"
#include <string.h>

#include "osenv.h"


int
xf86ReadBIOS(Base, Offset, Buf, Len)
	unsigned long Base;
	unsigned long Offset;
	unsigned char *Buf;
	int Len;
{
	oskit_addr_t base;
	int rc;

	
	if (rc = oskit_osenv_mem_mapphys(oskit_x11_oskit_osenv_mem,
					 Base + Offset, Len, &base, 0))
		return -1;

	bcopy(base, Buf, Len);

#ifdef NOTYET
	osenv_mem_unmap_phys(Base + Offset, Len);
#endif

	return Len;
}
